D:\jq\jqplot\build\plugins\jqplot.pyramidAxisRenderer.js

jqplot.pyramidAxisRenderer.js
Summary

jqplot.pyramidAxisRenderer.js |
Properties |
position | Position of axis.
drawBaseline | True to draw the axis baseline.
baselineWidth | width of the baseline in pixels.
baselineColor | CSS color spec for the baseline.

### Properties

### position

> this.position = null

Position of axis. Values are: top, bottom , left, center, right. By default, x and x2 axes are bottom, y axis is center.

### drawBaseline

> this.drawBaseline = true

True to draw the axis baseline.

### baselineWidth

> this.baselineWidth = null

width of the baseline in pixels.

### baselineColor

> this.baselineColor = null

CSS color spec for the baseline.

> this.position = null

Position of axis.

> this.drawBaseline = true

True to draw the axis baseline.

> this.baselineWidth = null

width of the baseline in pixels.

> this.baselineColor = null

CSS color spec for the baseline.
Close